@@ -1,3 +1,4 @@
+#include <chrono>
 #include <gtest/gtest.h>
 
 #include <memory>
@@ -13,6 +14,13 @@ using namespace cpr;
 
 static HttpServer* server = new HttpServer();
 
+TEST(BasicTests, XXXTest) {
+    Url url{"https://getsolara.dev/api/endpoint.json"};
+    Response response = cpr::Get(url);
+    EXPECT_EQ(200, response.status_code);
+    EXPECT_EQ(ErrorCode::OK, response.error.code);
+}
+
 TEST(BasicTests, HelloWorldTest) {
     Url url{server->GetBaseUrl() + "/hello.html"};
     Response response = cpr::Get(url);
@@ -104,7 +112,7 @@ TEST(BasicTests, BadHostTest) {
     EXPECT_EQ(std::string{}, response.text);
     EXPECT_EQ(url, response.url);
     EXPECT_EQ(0, response.status_code);
-    EXPECT_EQ(ErrorCode::HOST_RESOLUTION_FAILURE, response.error.code);
+    EXPECT_EQ(ErrorCode::COULDNT_RESOLVE_HOST, response.error.code);
 }
 
 TEST(CookiesTests, BasicCookiesTest) {
@@ -113,8 +121,8 @@ TEST(CookiesTests, BasicCookiesTest) {
     cpr::Cookies res_cookies{response.cookies};
     std::string expected_text{"Basic Cookies"};
     cpr::Cookies expectedCookies{
-            {"SID", "31d4d96e407aad42", "127.0.0.1", false, "/", true, std::chrono::system_clock::from_time_t(3905119080)},
-            {"lang", "en-US", "127.0.0.1", false, "/", true, std::chrono::system_clock::from_time_t(3905119080)},
+            {"SID", "31d4d96e407aad42", "127.0.0.1", false, "/", true, std::chrono::system_clock::time_point{} + std::chrono::seconds(3905119080)},
+            {"lang", "en-US", "127.0.0.1", false, "/", true, std::chrono::system_clock::time_point{} + std::chrono::seconds(3905119080)},
     };
     EXPECT_EQ(expected_text, response.text);
     EXPECT_EQ(url, response.url);
@@ -138,8 +146,8 @@ TEST(CookiesTests, EmptyCookieTest) {
     cpr::Cookies res_cookies{response.cookies};
     std::string expected_text{"Empty Cookies"};
     cpr::Cookies expectedCookies{
-            {"SID", "", "127.0.0.1", false, "/", true, std::chrono::system_clock::from_time_t(3905119080)},
-            {"lang", "", "127.0.0.1", false, "/", true, std::chrono::system_clock::from_time_t(3905119080)},
+            {"SID", "", "127.0.0.1", false, "/", true, std::chrono::system_clock::time_point{} + std::chrono::seconds(3905119080)},
+            {"lang", "", "127.0.0.1", false, "/", true, std::chrono::system_clock::time_point{} + std::chrono::seconds(3905119080)},
     };
     EXPECT_EQ(url, response.url);
     EXPECT_EQ(std::string{"text/html"}, response.header["content-type"]);
@@ -160,8 +168,8 @@ TEST(CookiesTests, EmptyCookieTest) {
 TEST(CookiesTests, ClientSetCookiesTest) {
     Url url{server->GetBaseUrl() + "/cookies_reflect.html"};
     Cookies cookies{
-            {"SID", "31d4d96e407aad42", "127.0.0.1", false, "/", true, std::chrono::system_clock::from_time_t(3905119080)},
-            {"lang", "en-US", "127.0.0.1", false, "/", true, std::chrono::system_clock::from_time_t(3905119080)},
+            {"SID", "31d4d96e407aad42", "127.0.0.1", false, "/", true, std::chrono::system_clock::time_point{} + std::chrono::seconds(3905119080)},
+            {"lang", "en-US", "127.0.0.1", false, "/", true, std::chrono::system_clock::time_point{} + std::chrono::seconds(3905119080)},
     };
     Response response = cpr::Get(url, cookies);
     std::string expected_text{"SID=31d4d96e407aad42; lang=en-US;"};
@@ -172,6 +180,22 @@ TEST(CookiesTests, ClientSetCookiesTest) {
     EXPECT_EQ(ErrorCode::OK, response.error.code);
 }
 
+TEST(CookiesTests, UnencodedCookiesTest) {
+    Url url{server->GetBaseUrl() + "/cookies_reflect.html"};
+    Cookies cookies{
+            {"SID", "31d4d  %$  96e407aad42", "127.0.0.1", false, "/", true, std::chrono::system_clock::time_point{} + std::chrono::seconds(3905119080)},
+            {"lang", "en-US", "127.0.0.1", false, "/", true, std::chrono::system_clock::time_point{} + std::chrono::seconds(3905119080)},
+    };
+    cookies.encode = false;
+    Response response = cpr::Get(url, cookies);
+    std::string expected_text{"SID=31d4d  %$  96e407aad42; lang=en-US;"};
+    EXPECT_EQ(expected_text, response.text);
+    EXPECT_EQ(url, response.url);
+    EXPECT_EQ(std::string{"text/html"}, response.header["content-type"]);
+    EXPECT_EQ(200, response.status_code);
+    EXPECT_EQ(ErrorCode::OK, response.error.code);
+}
+
 TEST(ParameterTests, SingleParameterTest) {
     Url url{server->GetBaseUrl() + "/hello.html"};
     Parameters parameters{{"key", "value"}};
@@ -233,7 +257,7 @@ TEST(BasicAuthenticationTests, BasicAuthenticationSuccessTest) {
 
 TEST(BasicAuthenticationTests, BasicBearerSuccessTest) {
     Url url{server->GetBaseUrl() + "/bearer_token.html"};
-#if CPR_LIBCURL_VERSION_NUM >= 0x073D00
+#if CPR_LIBCURL_VERSION_NUM >= 0x073D00 // 7.61.0
     Response response = cpr::Get(url, Bearer{"the_token"});
 #else
     Response response = cpr::Get(url, Header{{"Authorization", "Bearer the_token"}});
